Ori.livneh has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/278706

Change subject: Add Australia to NavTiming countries
......................................................................

Add Australia to NavTiming countries

Follows I1d524cdb9 and I448a5fe61. Add Australia, because it has a large
userbase and because it's remote from, like, everything. We also get to have a
graph for Oceania that way.

Change-Id: I12957a082e9dd5b5c1a2b14b16ab7ed7a6c74cf5
---
M modules/webperf/files/navtiming.py
1 file changed, 7 insertions(+), 5 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/operations/puppet 
refs/changes/06/278706/1

diff --git a/modules/webperf/files/navtiming.py 
b/modules/webperf/files/navtiming.py
index 84890e0..c933bdc 100755
--- a/modules/webperf/files/navtiming.py
+++ b/modules/webperf/files/navtiming.py
@@ -65,9 +65,11 @@
         iso_3166_countries[country] = continent
 
 # Map of ISO 3166-1 country codes to country name, with entries for the world's
-# 40 most populous countries as of 1 January 2016. About 83% of the world's
-# population lives in one of these countries.
-iso_3166_top_40 = {
+# 40 most populous countries as of 1 January 2016, plus Australia. About 83% of
+# the world's population lives in one of these countries. Australia is included
+# because it has a large user base while being remote from anywhere else.
+# Australia
+iso_3166_top_40_plus_australia = {
     'AR': 'Argentina',      'BD': 'Bangladesh',       'BR': 'Brazil',
     'CA': 'Canada',         'CD': 'DR Congo',         'CN': 'China',
     'CO': 'Colombia',       'DE': 'Germany',          'DZ': 'Algeria',
@@ -81,7 +83,7 @@
     'SA': 'Saudi Arabia',   'SD': 'Sudan',            'TH': 'Thailand',
     'TR': 'Turkey',         'TZ': 'Tanzania',         'UA': 'Ukraine',
     'UG': 'Uganda',         'US': 'United States',    'VN': 'Vietnam',
-    'ZA': 'South Africa',
+    'ZA': 'South Africa',   'AU': 'Australia',
 }
 
 
@@ -261,7 +263,7 @@
 
     country_code = event.get('originCountry')
     continent = iso_3166_countries.get(country_code)
-    country_name = iso_3166_top_40.get(country_code)
+    country_name = iso_3166_top_40_plus_australia.get(country_code)
 
     if 'sslNegotiation' in metrics:
         metrics = {'sslNegotiation': metrics['sslNegotiation']}

-- 
To view, visit https://gerrit.wikimedia.org/r/278706
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I12957a082e9dd5b5c1a2b14b16ab7ed7a6c74cf5
Gerrit-PatchSet: 1
Gerrit-Project: operations/puppet
Gerrit-Branch: production
Gerrit-Owner: Ori.livneh <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to